# The File Tool

  ## Description

  The File Tool aims to centralize all of the file related needs a python programmer might need into a single python library. Functionally it acts as a wrapper for many other libraries allowing them to interact and acomplish file related tasks without the need for coding functions to handle conversions. The intial version of this project was created as a hack at the MLH sponsored Hack@URI 2026.

  ## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Tests](#tests)
- [Contributing](#contributing)
- [Questions](#questions)
- [License](#license)

## Installation

Install using pip the_file_tool (Instructions pending)

## Usage

Below are some examples of use. Further examples and tests are included in the library and can be called using certain functions. Refer to documentation for more info.

## License

MIT

## Contributing

(List any used Libraries)

## Tests

Test file conversion, test error handling, test file editing (subject to change).

## Questions

Contact me: [GitHub](github.com/Xydra01)

---
